"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class SessionQuery(google.protobuf.message.Message):
    """*
    This message is used to initialized or request a session.
    @author Alexander McService Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    SCENE_NAME_FIELD_NUMBER: builtins.int
    TASK_NAME_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    id: builtins.str
    """/ unique id of a session; will be created by `SessionService`"""
    user_id: builtins.int
    """/ user assigned to the session"""
    scene_name: builtins.str
    """/ location assigned to the session"""
    task_name: builtins.str
    """/ task assigned to the session"""
    username: builtins.str
    """/ resolves assigned `user_id` from `username`"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        user_id: builtins.int = ...,
        scene_name: builtins.str = ...,
        task_name: builtins.str = ...,
        username: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "scene_name", b"scene_name", "task_name", b"task_name", "user_id", b"user_id", "username", b"username"]) -> None: ...

global___SessionQuery = SessionQuery



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.assistance.task_step_pb2
import avikom.generic.key_value_pair_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Task(google.protobuf.message.Message):
    """*
    This message describes a specific Task which can include several task steps.
    A task may be conducted in several locations (scenes). 
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    STEPS_FIELD_NUMBER: builtins.int
    SUMMARY_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PROCESS_FIELD_NUMBER: builtins.int
    PROCESS_PARAMETERS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """/ globally unique name of the task"""
    @property
    def steps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.assistance.task_step_pb2.TaskStep]:
        """/ steps assigned to this task; steps do not need to be exclusive to a task; steps do not need to be mentioned here to be triggered by tge BPM engine"""
    summary: builtins.str
    """/ a brief description of the current task (roughly 1-3 sentences max)."""
    description: builtins.str
    """/ a more detailled description of the task at hand"""
    process: builtins.str
    """/ name of the BPM process that describes this task"""
    @property
    def process_parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.generic.key_value_pair_pb2.KeyValuePair]:
        """/ variables passed to the process"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        steps: collections.abc.Iterable[avikom.assistance.task_step_pb2.TaskStep] | None = ...,
        summary: builtins.str = ...,
        description: builtins.str = ...,
        process: builtins.str = ...,
        process_parameters: collections.abc.Iterable[avikom.generic.key_value_pair_pb2.KeyValuePair] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name", "process", b"process", "process_parameters", b"process_parameters", "steps", b"steps", "summary", b"summary"]) -> None: ...

global___Task = Task



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ServerToClient(google.protobuf.message.Message):
    """*
    A message to be sent from a server to a tunneled client.
    Clients need to resolve the (local) method name and assign the correct message IDs to responses
    sent back to the server.
    Note that method names may differ depending on the client's language.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METHOD_FIELD_NUMBER: builtins.int
    REQUEST_FIELD_NUMBER: builtins.int
    MESSAGE_ID_FIELD_NUMBER: builtins.int
    method: builtins.str
    """/ Method name in CapitalCase since this is the default proto style"""
    request: builtins.bytes
    """/ A message as a byte string; needs to be parsed and forwarded to the local gRPC server"""
    message_id: builtins.int
    """/ An ID associated with the request; A response must contain the correct ID!"""
    def __init__(
        self,
        *,
        method: builtins.str = ...,
        request: builtins.bytes = ...,
        message_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message_id", b"message_id", "method", b"method", "request", b"request"]) -> None: ...

global___ServerToClient = ServerToClient



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/instruction_meta.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.assistance import assistance_level_pb2 as avikom_dot_assistance_dot_assistance__level__pb2
from avikom.generic import modality_pb2 as avikom_dot_generic_dot_modality__pb2
from avikom.unity import transpose_pb2 as avikom_dot_unity_dot_transpose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(avikom/assistance/instruction_meta.proto\x12\x11\x61vikom.assistance\x1a(avikom/assistance/assistance_level.proto\x1a\x1d\x61vikom/generic/modality.proto\x1a\x1c\x61vikom/unity/transpose.proto\"\xc7\x01\n\x0fInstructionMeta\x12<\n\x10\x61ssistance_level\x18\x01 \x01(\x0e\x32\".avikom.assistance.AssistanceLevel\x12,\n\nmodal_bias\x18\x02 \x01(\x0b\x32\x18.avikom.generic.Modality\x12\x10\n\x08location\x18\x03 \x01(\t\x12*\n\ttranspose\x18\x04 \x01(\x0b\x32\x17.avikom.unity.Transpose\x12\n\n\x02id\x18\x05 \x01(\tBu\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.instruction_meta_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _INSTRUCTIONMETA._serialized_start=167
  _INSTRUCTIONMETA._serialized_end=366
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/camunda/external_task.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.camunda import variable_pb2 as avikom_dot_camunda_dot_variable__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"avikom/camunda/external_task.proto\x12\x0e\x61vikom.camunda\x1a\x1d\x61vikom/camunda/variable.proto\"\xfe\x02\n\x0c\x45xternalTask\x12\x13\n\x0b\x61\x63tivity_id\x18\x01 \x01(\t\x12\x1c\n\x14\x61\x63tivity_instance_id\x18\x02 \x01(\t\x12\x15\n\rerror_message\x18\x03 \x01(\t\x12\x14\n\x0c\x65xecution_id\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x1c\n\x14lock_expiration_time\x18\x06 \x01(\t\x12\x1d\n\x15process_definition_id\x18\x07 \x01(\t\x12\x1e\n\x16process_definition_key\x18\x08 \x01(\t\x12\x1b\n\x13process_instance_id\x18\t \x01(\t\x12\x11\n\ttenant_id\x18\n \x01(\t\x12\x0f\n\x07retries\x18\x0b \x01(\x05\x12\x11\n\tworker_id\x18\x0c \x01(\t\x12\x10\n\x08priority\x18\r \x01(\x05\x12\x12\n\ntopic_name\x18\x0e \x01(\t\x12+\n\tvariables\x18\x0f \x03(\x0b\x32\x18.avikom.camunda.VariableBl\n\x18\x61pp.avikom.types.camundaZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/camunda\xaa\x02\x14\x41vikom.Types.Camundab\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.camunda.external_task_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.camundaZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/camunda\252\002\024Avikom.Types.Camunda'
  _EXTERNALTASK._serialized_start=86
  _EXTERNALTASK._serialized_end=468
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/vision/image_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61vikom/vision/image_info.proto\x12\ravikom.vision\"`\n\tImageInfo\x12\x0c\n\x04size\x18\x01 \x01(\x05\x12\x12\n\nchunk_size\x18\x02 \x01(\x05\x12\x12\n\ncompressed\x18\x03 \x01(\x08\x12\r\n\x05width\x18\x04 \x01(\x05\x12\x0e\n\x06height\x18\x05 \x01(\x05\x42i\n\x17\x61pp.avikom.types.visionZ8gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/vision\xaa\x02\x13\x41vikom.Types.Visionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.vision.image_info_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027app.avikom.types.visionZ8gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/vision\252\002\023Avikom.Types.Vision'
  _IMAGEINFO._serialized_start=49
  _IMAGEINFO._serialized_end=145
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Modality(google.protobuf.message.Message):
    """*
    A message specifying one of three- or a combination of three interaction modalities supported 
    for, for example, instructions, peers, user_profiles and sessions.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VISUAL_FIELD_NUMBER: builtins.int
    AUDITORY_FIELD_NUMBER: builtins.int
    TACTILE_FIELD_NUMBER: builtins.int
    visual: builtins.float
    """/ things you see (Sight)"""
    auditory: builtins.float
    """/ things you hear (Hearing)"""
    tactile: builtins.float
    """/ things you touch/feel (Touch)"""
    def __init__(
        self,
        *,
        visual: builtins.float = ...,
        auditory: builtins.float = ...,
        tactile: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["auditory", b"auditory", "tactile", b"tactile", "visual", b"visual"]) -> None: ...

global___Modality = Modality



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/task_storage_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.assistance import scene_pb2 as avikom_dot_assistance_dot_scene__pb2
from avikom.assistance import task_pb2 as avikom_dot_assistance_dot_task__pb2
from avikom.assistance import task_step_pb2 as avikom_dot_assistance_dot_task__step__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,avikom/assistance/task_storage_service.proto\x12\x11\x61vikom.assistance\x1a\x1d\x61vikom/assistance/scene.proto\x1a\x1c\x61vikom/assistance/task.proto\x1a!avikom/assistance/task_step.proto\x1a\x1b\x61vikom/generic/result.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\" \n\x10TaskStorageQuery\x12\x0c\n\x04name\x18\x01 \x01(\t\"5\n\tSceneList\x12(\n\x06scenes\x18\x01 \x03(\x0b\x32\x18.avikom.assistance.Scene\"2\n\x08TaskList\x12&\n\x05tasks\x18\x01 \x03(\x0b\x32\x17.avikom.assistance.Task\":\n\x0cTaskStepList\x12*\n\x05steps\x18\x01 \x03(\x0b\x32\x1b.avikom.assistance.TaskStep2\x98\n\n\x12TaskStorageService\x12[\n\x08\x41\x64\x64Scene\x12\x18.avikom.assistance.Scene\x1a\x16.avikom.generic.Result\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/storage/scenes:\x01*\x12{\n\x0bUpdateScene\x12\x18.avikom.assistance.Scene\x1a\x16.avikom.generic.Result\":\x82\xd3\xe4\x93\x02\x34\x32\x12/v1/storage/scenes:\x01*Z\x1b\x32\x19/v1/storage/scenes/{name}\x12l\n\x08GetScene\x12#.avikom.assistance.TaskStorageQuery\x1a\x18.avikom.assistance.Scene\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/storage/scenes/{name}\x12`\n\x0cGetAllScenes\x12\x16.google.protobuf.Empty\x1a\x1c.avikom.assistance.SceneList\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/storage/scenes\x12X\n\x07\x41\x64\x64Task\x12\x17.avikom.assistance.Task\x1a\x16.avikom.generic.Result\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/storage/tasks:\x01*\x12w\n\nUpdateTask\x12\x17.avikom.assistance.Task\x1a\x16.avikom.generic.Result\"8\x82\xd3\xe4\x93\x02\x32\x32\x11/v1/storage/tasks:\x01*Z\x1a\x32\x18/v1/storage/tasks/{name}\x12i\n\x07GetTask\x12#.avikom.assistance.TaskStorageQuery\x1a\x17.avikom.assistance.Task\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/storage/tasks/{name}\x12]\n\x0bGetAllTasks\x12\x16.google.protobuf.Empty\x1a\x1b.avikom.assistance.TaskList\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/storage/tasks\x12`\n\x0b\x41\x64\x64TaskStep\x12\x1b.avikom.assistance.TaskStep\x1a\x16.avikom.generic.Result\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/storage/steps:\x01*\x12\x7f\n\x0eUpdateTaskStep\x12\x1b.avikom.assistance.TaskStep\x1a\x16.avikom.generic.Result\"8\x82\xd3\xe4\x93\x02\x32\x32\x11/v1/storage/steps:\x01*Z\x1a\x32\x18/v1/storage/steps/{name}\x12q\n\x0bGetTaskStep\x12#.avikom.assistance.TaskStorageQuery\x1a\x1b.avikom.assistance.TaskStep\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/storage/steps/{name}\x12\x65\n\x0fGetAllTaskSteps\x12\x16.google.protobuf.Empty\x1a\x1f.avikom.assistance.TaskStepList\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/storage/stepsBu\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.task_storage_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _TASKSTORAGESERVICE.methods_by_name['AddScene']._options = None
  _TASKSTORAGESERVICE.methods_by_name['AddScene']._serialized_options = b'\202\323\344\223\002\027\"\022/v1/storage/scenes:\001*'
  _TASKSTORAGESERVICE.methods_by_name['UpdateScene']._options = None
  _TASKSTORAGESERVICE.methods_by_name['UpdateScene']._serialized_options = b'\202\323\344\223\00242\022/v1/storage/scenes:\001*Z\0332\031/v1/storage/scenes/{name}'
  _TASKSTORAGESERVICE.methods_by_name['GetScene']._options = None
  _TASKSTORAGESERVICE.methods_by_name['GetScene']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/storage/scenes/{name}'
  _TASKSTORAGESERVICE.methods_by_name['GetAllScenes']._options = None
  _TASKSTORAGESERVICE.methods_by_name['GetAllScenes']._serialized_options = b'\202\323\344\223\002\024\022\022/v1/storage/scenes'
  _TASKSTORAGESERVICE.methods_by_name['AddTask']._options = None
  _TASKSTORAGESERVICE.methods_by_name['AddTask']._serialized_options = b'\202\323\344\223\002\026\"\021/v1/storage/tasks:\001*'
  _TASKSTORAGESERVICE.methods_by_name['UpdateTask']._options = None
  _TASKSTORAGESERVICE.methods_by_name['UpdateTask']._serialized_options = b'\202\323\344\223\00222\021/v1/storage/tasks:\001*Z\0322\030/v1/storage/tasks/{name}'
  _TASKSTORAGESERVICE.methods_by_name['GetTask']._options = None
  _TASKSTORAGESERVICE.methods_by_name['GetTask']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/storage/tasks/{name}'
  _TASKSTORAGESERVICE.methods_by_name['GetAllTasks']._options = None
  _TASKSTORAGESERVICE.methods_by_name['GetAllTasks']._serialized_options = b'\202\323\344\223\002\023\022\021/v1/storage/tasks'
  _TASKSTORAGESERVICE.methods_by_name['AddTaskStep']._options = None
  _TASKSTORAGESERVICE.methods_by_name['AddTaskStep']._serialized_options = b'\202\323\344\223\002\026\"\021/v1/storage/steps:\001*'
  _TASKSTORAGESERVICE.methods_by_name['UpdateTaskStep']._options = None
  _TASKSTORAGESERVICE.methods_by_name['UpdateTaskStep']._serialized_options = b'\202\323\344\223\00222\021/v1/storage/steps:\001*Z\0322\030/v1/storage/steps/{name}'
  _TASKSTORAGESERVICE.methods_by_name['GetTaskStep']._options = None
  _TASKSTORAGESERVICE.methods_by_name['GetTaskStep']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/storage/steps/{name}'
  _TASKSTORAGESERVICE.methods_by_name['GetAllTaskSteps']._options = None
  _TASKSTORAGESERVICE.methods_by_name['GetAllTaskSteps']._serialized_options = b'\202\323\344\223\002\023\022\021/v1/storage/steps'
  _TASKSTORAGEQUERY._serialized_start=251
  _TASKSTORAGEQUERY._serialized_end=283
  _SCENELIST._serialized_start=285
  _SCENELIST._serialized_end=338
  _TASKLIST._serialized_start=340
  _TASKLIST._serialized_end=390
  _TASKSTEPLIST._serialized_start=392
  _TASKSTEPLIST._serialized_end=450
  _TASKSTORAGESERVICE._serialized_start=453
  _TASKSTORAGESERVICE._serialized_end=1757
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/headset/rasa_message.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import key_value_pair_pb2 as avikom_dot_generic_dot_key__value__pair__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!avikom/headset/rasa_message.proto\x12\x0e\x61vikom.headset\x1a#avikom/generic/key_value_pair.proto\"[\n\x0bRasaMessage\x12\x0e\n\x06intent\x18\x01 \x01(\t\x12+\n\x05slots\x18\x02 \x03(\x0b\x32\x1c.avikom.generic.KeyValuePair\x12\x0f\n\x07user_id\x18\x03 \x01(\x04\x42l\n\x18\x61pp.avikom.types.headsetZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/headset\xaa\x02\x14\x41vikom.Types.Headsetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.headset.rasa_message_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.headsetZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/headset\252\002\024Avikom.Types.Headset'
  _RASAMESSAGE._serialized_start=90
  _RASAMESSAGE._serialized_end=181
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.generic.key_value_pair_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class RasaMessage(google.protobuf.message.Message):
    """*
    A RasaMessage provides the intents and slots recognized by rasa for a specific user.
    @author Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTENT_FIELD_NUMBER: builtins.int
    SLOTS_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    intent: builtins.str
    """/ the recognized intention of the user input"""
    @property
    def slots(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.generic.key_value_pair_pb2.KeyValuePair]:
        """/ additional information extracted from user input as key-value pairs"""
    user_id: builtins.int
    """/ the user who provided the input"""
    def __init__(
        self,
        *,
        intent: builtins.str = ...,
        slots: collections.abc.Iterable[avikom.generic.key_value_pair_pb2.KeyValuePair] | None = ...,
        user_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["intent", b"intent", "slots", b"slots", "user_id", b"user_id"]) -> None: ...

global___RasaMessage = RasaMessage



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from avikom.assistance import scene_pb2 as avikom_dot_assistance_dot_scene__pb2
from avikom.assistance import task_pb2 as avikom_dot_assistance_dot_task__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class SceneConsumerServiceStub(object):
    """*
    A scene consumer gets a copy of the currently set scene. It's also possible
    to only update the task of the current scene to enable 'side-tracking' when
    necessary.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetScene = channel.unary_unary(
                '/avikom.assistance.SceneConsumerService/SetScene',
                request_serializer=avikom_dot_assistance_dot_scene__pb2.Scene.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.GetScene = channel.unary_unary(
                '/avikom.assistance.SceneConsumerService/GetScene',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=avikom_dot_assistance_dot_scene__pb2.Scene.FromString,
                )
        self.SetTask = channel.unary_unary(
                '/avikom.assistance.SceneConsumerService/SetTask',
                request_serializer=avikom_dot_assistance_dot_task__pb2.Task.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )


class SceneConsumerServiceServicer(object):
    """*
    A scene consumer gets a copy of the currently set scene. It's also possible
    to only update the task of the current scene to enable 'side-tracking' when
    necessary.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def SetScene(self, request, context):
        """/ Sets the context of the task to be conducted. May or may not be considered by the consumer.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetScene(self, request, context):
        """/ Returns the currently set scene.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetTask(self, request, context):
        """/ Sets the task that is currently conducted. May or may not be considered by the consumer.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SceneConsumerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetScene': grpc.unary_unary_rpc_method_handler(
                    servicer.SetScene,
                    request_deserializer=avikom_dot_assistance_dot_scene__pb2.Scene.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'GetScene': grpc.unary_unary_rpc_method_handler(
                    servicer.GetScene,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=avikom_dot_assistance_dot_scene__pb2.Scene.SerializeToString,
            ),
            'SetTask': grpc.unary_unary_rpc_method_handler(
                    servicer.SetTask,
                    request_deserializer=avikom_dot_assistance_dot_task__pb2.Task.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'avikom.assistance.SceneConsumerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SceneConsumerService(object):
    """*
    A scene consumer gets a copy of the currently set scene. It's also possible
    to only update the task of the current scene to enable 'side-tracking' when
    necessary.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    @staticmethod
    def SetScene(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.SceneConsumerService/SetScene',
            avikom_dot_assistance_dot_scene__pb2.Scene.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetScene(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.SceneConsumerService/GetScene',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            avikom_dot_assistance_dot_scene__pb2.Scene.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.SceneConsumerService/SetTask',
            avikom_dot_assistance_dot_task__pb2.Task.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/runtime_step_list.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.assistance import runtime_task_step_pb2 as avikom_dot_assistance_dot_runtime__task__step__pb2
from avikom.generic import peer_pb2 as avikom_dot_generic_dot_peer__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)avikom/assistance/runtime_step_list.proto\x12\x11\x61vikom.assistance\x1a)avikom/assistance/runtime_task_step.proto\x1a\x19\x61vikom/generic/peer.proto\"i\n\x0fRuntimeStepList\x12\x31\n\x05steps\x18\x01 \x03(\x0b\x32\".avikom.assistance.RuntimeTaskStep\x12#\n\x05peers\x18\x02 \x03(\x0b\x32\x14.avikom.generic.PeerBu\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.runtime_step_list_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _RUNTIMESTEPLIST._serialized_start=134
  _RUNTIMESTEPLIST._serialized_end=239
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/tracking/gaze_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"avikom/tracking/gaze_service.proto\x12\x0f\x61vikom.tracking\x1a\x1bgoogle/protobuf/empty.proto\"\x18\n\nGazeTarget\x12\n\n\x02id\x18\x01 \x01(\t2W\n\x0bGazeService\x12H\n\rFocusedObject\x12\x16.google.protobuf.Empty\x1a\x1b.avikom.tracking.GazeTarget\"\x00\x30\x01\x42o\n\x19\x61pp.avikom.types.trackingZ:gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/tracking\xaa\x02\x15\x41vikom.Types.Trackingb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.tracking.gaze_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031app.avikom.types.trackingZ:gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/tracking\252\002\025Avikom.Types.Tracking'
  _GAZETARGET._serialized_start=84
  _GAZETARGET._serialized_end=108
  _GAZESERVICE._serialized_start=110
  _GAZESERVICE._serialized_end=197
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from avikom.glasses import media_info_pb2 as avikom_dot_glasses_dot_media__info__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class MediaFollowerServiceStub(object):
    """*
    A media follower receives events such as playing a video or stopping it and extends the user experience accordingly.
    For instance, an audio peer might play the (processed) audio stream of a video. 
    Media followers are passive and need to be addressed to get the required information.
    Whether pause and stop require individual treatment depends on the follower in question.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Play = channel.unary_unary(
                '/avikom.glasses.MediaFollowerService/Play',
                request_serializer=avikom_dot_glasses_dot_media__info__pb2.MediaInfo.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.Pause = channel.unary_unary(
                '/avikom.glasses.MediaFollowerService/Pause',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.Stop = channel.unary_unary(
                '/avikom.glasses.MediaFollowerService/Stop',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )


class MediaFollowerServiceServicer(object):
    """*
    A media follower receives events such as playing a video or stopping it and extends the user experience accordingly.
    For instance, an audio peer might play the (processed) audio stream of a video. 
    Media followers are passive and need to be addressed to get the required information.
    Whether pause and stop require individual treatment depends on the follower in question.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def Play(self, request, context):
        """/ informs the follower that a media file playback started
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Pause(self, request, context):
        """/ informs the follower that a media file has been paused
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stop(self, request, context):
        """/ informs the follower that a media file has been stopped
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MediaFollowerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Play': grpc.unary_unary_rpc_method_handler(
                    servicer.Play,
                    request_deserializer=avikom_dot_glasses_dot_media__info__pb2.MediaInfo.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'Pause': grpc.unary_unary_rpc_method_handler(
                    servicer.Pause,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'Stop': grpc.unary_unary_rpc_method_handler(
                    servicer.Stop,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'avikom.glasses.MediaFollowerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MediaFollowerService(object):
    """*
    A media follower receives events such as playing a video or stopping it and extends the user experience accordingly.
    For instance, an audio peer might play the (processed) audio stream of a video. 
    Media followers are passive and need to be addressed to get the required information.
    Whether pause and stop require individual treatment depends on the follower in question.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    @staticmethod
    def Play(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.glasses.MediaFollowerService/Play',
            avikom_dot_glasses_dot_media__info__pb2.MediaInfo.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Pause(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.glasses.MediaFollowerService/Pause',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Stop(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.glasses.MediaFollowerService/Stop',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _CommonUtterance:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CommonUtteranceEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CommonUtterance.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    COMMON_UTTERANCE_DEFAULT: _CommonUtterance.ValueType  # 0
    """/ generates no output"""
    COMMON_UTTERANCE_REPEAT: _CommonUtterance.ValueType  # 1
    """/ repeats the last speech output"""
    COMMON_UTTERANCE_APPROVE: _CommonUtterance.ValueType  # 2
    """/ utters a statement of confirmation i.e. "Ja" """
    COMMON_UTTERANCE_COMPLIMENT: _CommonUtterance.ValueType  # 3
    """/ utters a compliment i.e. "Toll! Weiter so." """

class CommonUtterance(_CommonUtterance, metaclass=_CommonUtteranceEnumTypeWrapper):
    """*
    This enum describes common utterances to be generated by the TTs engine and played back 
    on an auditory peer. 
    @author: Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

COMMON_UTTERANCE_DEFAULT: CommonUtterance.ValueType  # 0
"""/ generates no output"""
COMMON_UTTERANCE_REPEAT: CommonUtterance.ValueType  # 1
"""/ repeats the last speech output"""
COMMON_UTTERANCE_APPROVE: CommonUtterance.ValueType  # 2
"""/ utters a statement of confirmation i.e. "Ja" """
COMMON_UTTERANCE_COMPLIMENT: CommonUtterance.ValueType  # 3
"""/ utters a compliment i.e. "Toll! Weiter so." """
global___CommonUtterance = CommonUtterance



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class User(google.protobuf.message.Message):
    """*
    A message that contains data about a user that is essential for system operation.
    @author: Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIRST_NAME_FIELD_NUMBER: builtins.int
    LAST_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    USERNAMES_FIELD_NUMBER: builtins.int
    first_name: builtins.str
    """/ the first name is optional; will default to empty string if not"""
    last_name: builtins.str
    """/ the last name is optional; will default to empty string if not set"""
    id: builtins.int
    """/ does not need to be set when a new user is created"""
    @property
    def usernames(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """/ system usernames required for certain peers, preferarbly unique to prevent imposters"""
    def __init__(
        self,
        *,
        first_name: builtins.str = ...,
        last_name: builtins.str = ...,
        id: builtins.int = ...,
        usernames: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["first_name", b"first_name", "id", b"id", "last_name", b"last_name", "usernames", b"usernames"]) -> None: ...

global___User = User



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class PeerStorageQuery(google.protobuf.message.Message):
    """*
    A message including the name of the peer being queried
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """/ unique name of a peer"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___PeerStorageQuery = PeerStorageQuery



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/generic/logger_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#avikom/generic/logger_service.proto\x12\x0e\x61vikom.generic\x1a\x1b\x61vikom/generic/result.proto\x1a\x1cgoogle/api/annotations.proto\"S\n\x07Message\x12\'\n\x05level\x18\x01 \x01(\x0e\x32\x18.avikom.generic.LogLevel\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x0e\n\x06origin\x18\x03 \x01(\t*?\n\x08LogLevel\x12\t\n\x05\x44\x45\x42UG\x10\x00\x12\x08\n\x04INFO\x10\x01\x12\x08\n\x04WARN\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\t\n\x05\x46\x41TAL\x10\x04\x32\x95\x01\n\rLoggerService\x12\x83\x01\n\x03Log\x12\x17.avikom.generic.Message\x1a\x16.avikom.generic.Result\"K\x82\xd3\xe4\x93\x02\x45\"\n/v1/logger:\x01*Z\x15\"\x13/v1/logger/{origin}Z\x1d\"\x1b/v1/logger/{origin}/{level}Bl\n\x18\x61pp.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\xaa\x02\x14\x41vikom.Types.Genericb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.generic.logger_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\252\002\024Avikom.Types.Generic'
  _LOGGERSERVICE.methods_by_name['Log']._options = None
  _LOGGERSERVICE.methods_by_name['Log']._serialized_options = b'\202\323\344\223\002E\"\n/v1/logger:\001*Z\025\"\023/v1/logger/{origin}Z\035\"\033/v1/logger/{origin}/{level}'
  _LOGLEVEL._serialized_start=199
  _LOGLEVEL._serialized_end=262
  _MESSAGE._serialized_start=114
  _MESSAGE._serialized_end=197
  _LOGGERSERVICE._serialized_start=265
  _LOGGERSERVICE._serialized_end=414
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/generic/content_type.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!avikom/generic/content_type.proto\x12\x0e\x61vikom.generic*\xa9\x01\n\x0b\x43ontentType\x12\x13\n\x0f\x43ONTENT_UNKNOWN\x10\x00\x12\x11\n\rCONTENT_IMAGE\x10\x01\x12\x11\n\rCONTENT_VIDEO\x10\x02\x12\x10\n\x0c\x43ONTENT_TEXT\x10\x03\x12\x11\n\rCONTENT_AUDIO\x10\x04\x12\x12\n\x0e\x43ONTENT_VISUAL\x10\x05\x12\x14\n\x10\x43ONTENT_EXTERNAL\x10\x06\x12\x10\n\x0c\x43ONTENT_SSML\x10\x07\x42l\n\x18\x61pp.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\xaa\x02\x14\x41vikom.Types.Genericb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.generic.content_type_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\252\002\024Avikom.Types.Generic'
  _CONTENTTYPE._serialized_start=54
  _CONTENTTYPE._serialized_end=223
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from avikom.vision import image_info_pb2 as avikom_dot_vision_dot_image__info__pb2
from avikom.vision import image_pb2 as avikom_dot_vision_dot_image__pb2


class ImageServiceStub(object):
    """*
    Streams images and videos. An `ImageStream` will send images until the stream is closed by the client.
    Images are streamed in data chunks where the first chunk of each image is marked by `Image.info`.
    Every following chunk will have the `Imaga.data` field set until the next image starts.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetImage = channel.unary_stream(
                '/avikom.vision.ImageService/GetImage',
                request_serializer=avikom_dot_vision_dot_image__info__pb2.ImageInfo.SerializeToString,
                response_deserializer=avikom_dot_vision_dot_image__pb2.Image.FromString,
                )
        self.GetVideo = channel.unary_stream(
                '/avikom.vision.ImageService/GetVideo',
                request_serializer=avikom_dot_vision_dot_image__info__pb2.ImageInfo.SerializeToString,
                response_deserializer=avikom_dot_vision_dot_image__pb2.Image.FromString,
                )


class ImageServiceServicer(object):
    """*
    Streams images and videos. An `ImageStream` will send images until the stream is closed by the client.
    Images are streamed in data chunks where the first chunk of each image is marked by `Image.info`.
    Every following chunk will have the `Imaga.data` field set until the next image starts.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def GetImage(self, request, context):
        """/ returns an image and closes the connection aftewards
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVideo(self, request, context):
        """/ returns a series of image where each new image will be prepend with an `ImageInfo`
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ImageServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetImage': grpc.unary_stream_rpc_method_handler(
                    servicer.GetImage,
                    request_deserializer=avikom_dot_vision_dot_image__info__pb2.ImageInfo.FromString,
                    response_serializer=avikom_dot_vision_dot_image__pb2.Image.SerializeToString,
            ),
            'GetVideo': grpc.unary_stream_rpc_method_handler(
                    servicer.GetVideo,
                    request_deserializer=avikom_dot_vision_dot_image__info__pb2.ImageInfo.FromString,
                    response_serializer=avikom_dot_vision_dot_image__pb2.Image.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'avikom.vision.ImageService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ImageService(object):
    """*
    Streams images and videos. An `ImageStream` will send images until the stream is closed by the client.
    Images are streamed in data chunks where the first chunk of each image is marked by `Image.info`.
    Every following chunk will have the `Imaga.data` field set until the next image starts.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    @staticmethod
    def GetImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/avikom.vision.ImageService/GetImage',
            avikom_dot_vision_dot_image__info__pb2.ImageInfo.SerializeToString,
            avikom_dot_vision_dot_image__pb2.Image.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVideo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/avikom.vision.ImageService/GetVideo',
            avikom_dot_vision_dot_image__info__pb2.ImageInfo.SerializeToString,
            avikom_dot_vision_dot_image__pb2.Image.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/generic/user_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import user_pb2 as avikom_dot_generic_dot_user__pb2
from avikom.generic import user_profile_pb2 as avikom_dot_generic_dot_user__profile__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!avikom/generic/user_service.proto\x12\x0e\x61vikom.generic\x1a\x19\x61vikom/generic/user.proto\x1a!avikom/generic/user_profile.proto\x1a\x1cgoogle/api/annotations.proto2\x80\x04\n\x0bUserService\x12\xc5\x01\n\x07GetInfo\x12\x14.avikom.generic.User\x1a\x14.avikom.generic.User\"\x8d\x01\x82\xd3\xe4\x93\x02\x86\x01\x12\x11/v1/users/id/{id}Z#\x12!/v1/users/first_name/{first_name}Z!\x12\x1f/v1/users/last_name/{last_name}Z)\x12\'/v1/users/name/{first_name}/{last_name}\x12\xdb\x01\n\nGetProfile\x12\x14.avikom.generic.User\x1a\x1b.avikom.generic.UserProfile\"\x99\x01\x82\xd3\xe4\x93\x02\x92\x01\x12\x14/v1/profiles/id/{id}Z&\x12$/v1/profiles/first_name/{first_name}Z$\x12\"/v1/profiles/last_name/{last_name}Z,\x12*/v1/profiles/name/{first_name}/{last_name}\x12K\n\x07\x41\x64\x64User\x12\x14.avikom.generic.User\x1a\x14.avikom.generic.User\"\x14\x82\xd3\xe4\x93\x02\x0e\"\t/v1/users:\x01*Bl\n\x18\x61pp.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\xaa\x02\x14\x41vikom.Types.Genericb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.generic.user_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\252\002\024Avikom.Types.Generic'
  _USERSERVICE.methods_by_name['GetInfo']._options = None
  _USERSERVICE.methods_by_name['GetInfo']._serialized_options = b'\202\323\344\223\002\206\001\022\021/v1/users/id/{id}Z#\022!/v1/users/first_name/{first_name}Z!\022\037/v1/users/last_name/{last_name}Z)\022\'/v1/users/name/{first_name}/{last_name}'
  _USERSERVICE.methods_by_name['GetProfile']._options = None
  _USERSERVICE.methods_by_name['GetProfile']._serialized_options = b'\202\323\344\223\002\222\001\022\024/v1/profiles/id/{id}Z&\022$/v1/profiles/first_name/{first_name}Z$\022\"/v1/profiles/last_name/{last_name}Z,\022*/v1/profiles/name/{first_name}/{last_name}'
  _USERSERVICE.methods_by_name['AddUser']._options = None
  _USERSERVICE.methods_by_name['AddUser']._serialized_options = b'\202\323\344\223\002\016\"\t/v1/users:\001*'
  _USERSERVICE._serialized_start=146
  _USERSERVICE._serialized_end=658
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.unity.game_object_pb2
import avikom.unity.waypoint_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class SceneConfig(google.protobuf.message.Message):
    """*
    This message describes a scene config and contains location-bound parameters.
    It should also provide semantic anchors for task-specific configurations to be attached. 
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCENE_NAME_FIELD_NUMBER: builtins.int
    ANCHORS_FIELD_NUMBER: builtins.int
    ASSETS_FIELD_NUMBER: builtins.int
    WAYPOINTS_FIELD_NUMBER: builtins.int
    scene_name: builtins.str
    """/ name of the scene the configuration belongs to"""
    @property
    def anchors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.unity.game_object_pb2.GameObject]:
        """/ marked locations that synchronize the real and virtual environment; most likely QR codes"""
    @property
    def assets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.unity.game_object_pb2.GameObject]:
        """/ objects that are positioned in the scene; may act as anchors for task-specific configurations"""
    @property
    def waypoints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.unity.waypoint_pb2.Waypoint]:
        """/ coordinates that represents paths from one asset to antother. used to mark 'save' guidance routes"""
    def __init__(
        self,
        *,
        scene_name: builtins.str = ...,
        anchors: collections.abc.Iterable[avikom.unity.game_object_pb2.GameObject] | None = ...,
        assets: collections.abc.Iterable[avikom.unity.game_object_pb2.GameObject] | None = ...,
        waypoints: collections.abc.Iterable[avikom.unity.waypoint_pb2.Waypoint] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["anchors", b"anchors", "assets", b"assets", "scene_name", b"scene_name", "waypoints", b"waypoints"]) -> None: ...

global___SceneConfig = SceneConfig



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/headset/audio_peer_control_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from avikom.headset import functional_sound_pb2 as avikom_dot_headset_dot_functional__sound__pb2
from avikom.headset import common_utterance_pb2 as avikom_dot_headset_dot_common__utterance__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/avikom/headset/audio_peer_control_service.proto\x12\x0e\x61vikom.headset\x1a\x1b\x61vikom/generic/result.proto\x1a%avikom/headset/functional_sound.proto\x1a%avikom/headset/common_utterance.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\":\n\x14\x41udioPeerModeRequest\x12\"\n\x04mode\x18\x02 \x01(\x0e\x32\x14.avikom.headset.Mode\"h\n\x16\x46unctionalSoundRequest\x12\x39\n\x10\x66unctional_sound\x18\x02 \x01(\x0e\x32\x1f.avikom.headset.FunctionalSound\x12\x13\n\x0bother_sound\x18\x03 \x01(\t\"Z\n\nSayRequest\x12\x11\n\tutterance\x18\x02 \x01(\t\x12\x39\n\x10\x63ommon_utterance\x18\x03 \x01(\x0e\x32\x1f.avikom.headset.CommonUtterance*@\n\x04Mode\x12\x10\n\x0cMODE_UNKNOWN\x10\x00\x12\x10\n\x0cMODE_DEFAULT\x10\x01\x12\x14\n\x10MODE_TRANSPARENT\x10\x02\x32\xf0\x01\n\x17\x41udioPeerControlService\x12I\n\x07SetMode\x12$.avikom.headset.AudioPeerModeRequest\x1a\x16.avikom.generic.Result\"\x00\x12M\n\tPlaySound\x12&.avikom.headset.FunctionalSoundRequest\x1a\x16.avikom.generic.Result\"\x00\x12;\n\x03Say\x12\x1a.avikom.headset.SayRequest\x1a\x16.avikom.generic.Result\"\x00\x42l\n\x18\x61pp.avikom.types.headsetZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/headset\xaa\x02\x14\x41vikom.Types.Headsetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.headset.audio_peer_control_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.headsetZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/headset\252\002\024Avikom.Types.Headset'
  _MODE._serialized_start=491
  _MODE._serialized_end=555
  _AUDIOPEERMODEREQUEST._serialized_start=233
  _AUDIOPEERMODEREQUEST._serialized_end=291
  _FUNCTIONALSOUNDREQUEST._serialized_start=293
  _FUNCTIONALSOUNDREQUEST._serialized_end=397
  _SAYREQUEST._serialized_start=399
  _SAYREQUEST._serialized_end=489
  _AUDIOPEERCONTROLSERVICE._serialized_start=558
  _AUDIOPEERCONTROLSERVICE._serialized_end=798
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.generic.modality_pb2
import avikom.generic.rpc_endpoint_pb2
import avikom.generic.user_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Peer(google.protobuf.message.Message):
    """*
    A representation of a service system to connect to or to exchange data with.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    HOST_NAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    MODAL_FITNESS_FIELD_NUMBER: builtins.int
    GATEWAY_FIELD_NUMBER: builtins.int
    SERVICES_FIELD_NUMBER: builtins.int
    ENDPOINTS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """/ unique identifier of peer"""
    ip: builtins.str
    """/ the ip under which the peer can be reached"""
    host_name: builtins.str
    """/ name of the host; only interpreted if ip not set"""
    port: builtins.int
    """/ port under which the peer can be reached"""
    @property
    def user(self) -> avikom.generic.user_pb2.User:
        """/ the user currently associated with that peer"""
    @property
    def modal_fitness(self) -> avikom.generic.modality_pb2.Modality:
        """/ the modality or combination of modalities the peer supports"""
    gateway: builtins.str
    """/ a gateway URL in cases where the peer cannot be reached directly"""
    @property
    def services(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """/ a list of services the peer provides for task step resolution"""
    @property
    def endpoints(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[avikom.generic.rpc_endpoint_pb2.RpcEndpoint.ValueType]:
        """/ a list of endpoints that are provied by the peer"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        ip: builtins.str = ...,
        host_name: builtins.str = ...,
        port: builtins.int = ...,
        user: avikom.generic.user_pb2.User | None = ...,
        modal_fitness: avikom.generic.modality_pb2.Modality | None = ...,
        gateway: builtins.str = ...,
        services: collections.abc.Iterable[builtins.str] | None = ...,
        endpoints: collections.abc.Iterable[avikom.generic.rpc_endpoint_pb2.RpcEndpoint.ValueType] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["modal_fitness", b"modal_fitness", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoints", b"endpoints", "gateway", b"gateway", "host_name", b"host_name", "ip", b"ip", "modal_fitness", b"modal_fitness", "name", b"name", "port", b"port", "services", b"services", "user", b"user"]) -> None: ...

global___Peer = Peer

@typing_extensions.final
class PeerList(google.protobuf.message.Message):
    """*
    A list of peers that is commonly associated with steps and or runtime task steps.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PEERS_FIELD_NUMBER: builtins.int
    @property
    def peers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Peer]:
        """/ A list of peers."""
    def __init__(
        self,
        *,
        peers: collections.abc.Iterable[global___Peer] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["peers", b"peers"]) -> None: ...

global___PeerList = PeerList



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/unity/scene_config_storage_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from avikom.unity import scene_config_pb2 as avikom_dot_unity_dot_scene__config__pb2
from avikom.unity import task_config_pb2 as avikom_dot_unity_dot_task__config__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/avikom/unity/scene_config_storage_service.proto\x12\x0c\x61vikom.unity\x1a\x1b\x61vikom/generic/result.proto\x1a\x1f\x61vikom/unity/scene_config.proto\x1a\x1e\x61vikom/unity/task_config.proto\x1a\x1cgoogle/api/annotations.proto\"&\n\x10SceneConfigQuery\x12\x12\n\nscene_name\x18\x01 \x01(\t\"$\n\x0fTaskConfigQuery\x12\x11\n\ttask_name\x18\x01 \x01(\t2\xd4\x03\n\x19SceneConfigStorageService\x12\x45\n\x0e\x41\x64\x64SceneConfig\x12\x19.avikom.unity.SceneConfig\x1a\x16.avikom.generic.Result\"\x00\x12M\n\x0eGetSceneConfig\x12\x1e.avikom.unity.SceneConfigQuery\x1a\x19.avikom.unity.SceneConfig\"\x00\x12H\n\x11UpdateSceneConfig\x12\x19.avikom.unity.SceneConfig\x1a\x16.avikom.generic.Result\"\x00\x12\x43\n\rAddTaskConfig\x12\x18.avikom.unity.TaskConfig\x1a\x16.avikom.generic.Result\"\x00\x12J\n\rGetTaskConfig\x12\x1d.avikom.unity.TaskConfigQuery\x1a\x18.avikom.unity.TaskConfig\"\x00\x12\x46\n\x10UpdateTaskConfig\x12\x18.avikom.unity.TaskConfig\x1a\x16.avikom.generic.Result\"\x00\x42\x66\n\x16\x61pp.avikom.types.unityZ7gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/unity\xaa\x02\x12\x41vikom.Types.Unityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.unity.scene_config_storage_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026app.avikom.types.unityZ7gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/unity\252\002\022Avikom.Types.Unity'
  _SCENECONFIGQUERY._serialized_start=189
  _SCENECONFIGQUERY._serialized_end=227
  _TASKCONFIGQUERY._serialized_start=229
  _TASKCONFIGQUERY._serialized_end=265
  _SCENECONFIGSTORAGESERVICE._serialized_start=268
  _SCENECONFIGSTORAGESERVICE._serialized_end=736
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from avikom.assistance import issue_pb2 as avikom_dot_assistance_dot_issue__pb2
from avikom.assistance import issue_query_pb2 as avikom_dot_assistance_dot_issue__query__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2


class IssueServiceStub(object):
    """*
    This service manages issues. It should also communicate with `IssueStorageService` behind the scene for persisten issue management.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StartIssue = channel.unary_unary(
                '/avikom.assistance.IssueService/StartIssue',
                request_serializer=avikom_dot_assistance_dot_issue__query__pb2.IssueQuery.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.GetIssue = channel.unary_unary(
                '/avikom.assistance.IssueService/GetIssue',
                request_serializer=avikom_dot_assistance_dot_issue__query__pb2.IssueQuery.SerializeToString,
                response_deserializer=avikom_dot_assistance_dot_issue__pb2.IssueList.FromString,
                )


class IssueServiceServicer(object):
    """*
    This service manages issues. It should also communicate with `IssueStorageService` behind the scene for persisten issue management.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def StartIssue(self, request, context):
        """/ Starts a process for the queried issue.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIssue(self, request, context):
        """/ Returns a list of issues filtered by `IssueQuery`.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_IssueServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StartIssue': grpc.unary_unary_rpc_method_handler(
                    servicer.StartIssue,
                    request_deserializer=avikom_dot_assistance_dot_issue__query__pb2.IssueQuery.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'GetIssue': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIssue,
                    request_deserializer=avikom_dot_assistance_dot_issue__query__pb2.IssueQuery.FromString,
                    response_serializer=avikom_dot_assistance_dot_issue__pb2.IssueList.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'avikom.assistance.IssueService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class IssueService(object):
    """*
    This service manages issues. It should also communicate with `IssueStorageService` behind the scene for persisten issue management.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    @staticmethod
    def StartIssue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.IssueService/StartIssue',
            avikom_dot_assistance_dot_issue__query__pb2.IssueQuery.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIssue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.IssueService/GetIssue',
            avikom_dot_assistance_dot_issue__query__pb2.IssueQuery.SerializeToString,
            avikom_dot_assistance_dot_issue__pb2.IssueList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/glasses/interaction_type.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%avikom/glasses/interaction_type.proto\x12\x0e\x61vikom.glasses\x1a\x1b\x61vikom/generic/result.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto*\xc4\x01\n\x0fInteractionType\x12\x17\n\x13INTERACTION_UNKNOWN\x10\x00\x12\x13\n\x0fINTERACTION_TAP\x10\x01\x12\x14\n\x10INTERACTION_HOME\x10\x02\x12\x1b\n\x17INTERACTION_BUTTON_DOWN\x10\x03\x12\x19\n\x15INTERACTION_BUTTON_UP\x10\x04\x12\x1a\n\x16INTERACTION_DRAG_START\x10\x05\x12\x19\n\x15INTERACTION_DRAG_STOP\x10\x06\x42l\n\x18\x61pp.avikom.types.glassesZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/glasses\xaa\x02\x14\x41vikom.Types.Glassesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.glasses.interaction_type_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.glassesZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/glasses\252\002\024Avikom.Types.Glasses'
  _INTERACTIONTYPE._serialized_start=146
  _INTERACTIONTYPE._serialized_end=342
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from avikom.generic import user_pb2 as avikom_dot_generic_dot_user__pb2
from avikom.generic import user_profile_pb2 as avikom_dot_generic_dot_user__profile__pb2


class UserServiceStub(object):
    """*
    A service to create users and to get additional information about an incomplete user object. 
    For information retrieval, an incomplete user object must be identifiable, 
    so either the user_id or usernames must be defined.
    For creating a new user, an incomplete user object should contain essential information,
    such as usernames 
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetInfo = channel.unary_unary(
                '/avikom.generic.UserService/GetInfo',
                request_serializer=avikom_dot_generic_dot_user__pb2.User.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_user__pb2.User.FromString,
                )
        self.GetProfile = channel.unary_unary(
                '/avikom.generic.UserService/GetProfile',
                request_serializer=avikom_dot_generic_dot_user__pb2.User.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_user__profile__pb2.UserProfile.FromString,
                )
        self.AddUser = channel.unary_unary(
                '/avikom.generic.UserService/AddUser',
                request_serializer=avikom_dot_generic_dot_user__pb2.User.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_user__pb2.User.FromString,
                )


class UserServiceServicer(object):
    """*
    A service to create users and to get additional information about an incomplete user object. 
    For information retrieval, an incomplete user object must be identifiable, 
    so either the user_id or usernames must be defined.
    For creating a new user, an incomplete user object should contain essential information,
    such as usernames 
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def GetInfo(self, request, context):
        """/ expects an incomplete user object (needs to be identifiable) and will return a (hopefully) complete User or the default user (id = 0)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProfile(self, request, context):
        """/ expects an incomplete user object (needs to be identifiable) and will return the profile of that user or an error (if user not found)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddUser(self, request, context):
        """/ expects an incomplete user object (essential information should be set, user_id should not be set); creates a user and returns the created user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInfo,
                    request_deserializer=avikom_dot_generic_dot_user__pb2.User.FromString,
                    response_serializer=avikom_dot_generic_dot_user__pb2.User.SerializeToString,
            ),
            'GetProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProfile,
                    request_deserializer=avikom_dot_generic_dot_user__pb2.User.FromString,
                    response_serializer=avikom_dot_generic_dot_user__profile__pb2.UserProfile.SerializeToString,
            ),
            'AddUser': grpc.unary_unary_rpc_method_handler(
                    servicer.AddUser,
                    request_deserializer=avikom_dot_generic_dot_user__pb2.User.FromString,
                    response_serializer=avikom_dot_generic_dot_user__pb2.User.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'avikom.generic.UserService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UserService(object):
    """*
    A service to create users and to get additional information about an incomplete user object. 
    For information retrieval, an incomplete user object must be identifiable, 
    so either the user_id or usernames must be defined.
    For creating a new user, an incomplete user object should contain essential information,
    such as usernames 
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    @staticmethod
    def GetInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.generic.UserService/GetInfo',
            avikom_dot_generic_dot_user__pb2.User.SerializeToString,
            avikom_dot_generic_dot_user__pb2.User.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.generic.UserService/GetProfile',
            avikom_dot_generic_dot_user__pb2.User.SerializeToString,
            avikom_dot_generic_dot_user__profile__pb2.UserProfile.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.generic.UserService/AddUser',
            avikom_dot_generic_dot_user__pb2.User.SerializeToString,
            avikom_dot_generic_dot_user__pb2.User.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from avikom.unity import asset_bundle_pb2 as avikom_dot_unity_dot_asset__bundle__pb2
from avikom.unity import asset_bundle_service_pb2 as avikom_dot_unity_dot_asset__bundle__service__pb2


class AssetBundleServiceStub(object):
    """
    Provides an interface to request AssetBundles from a server. 
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_stream(
                '/avikom.unity.AssetBundleService/Get',
                request_serializer=avikom_dot_unity_dot_asset__bundle__service__pb2.AssetBundleQuery.SerializeToString,
                response_deserializer=avikom_dot_unity_dot_asset__bundle__pb2.AssetBundle.FromString,
                )


class AssetBundleServiceServicer(object):
    """
    Provides an interface to request AssetBundles from a server. 
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def Get(self, request, context):
        """returns an asset bundle in binary chunks
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AssetBundleServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_stream_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=avikom_dot_unity_dot_asset__bundle__service__pb2.AssetBundleQuery.FromString,
                    response_serializer=avikom_dot_unity_dot_asset__bundle__pb2.AssetBundle.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'avikom.unity.AssetBundleService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AssetBundleService(object):
    """
    Provides an interface to request AssetBundles from a server. 
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/avikom.unity.AssetBundleService/Get',
            avikom_dot_unity_dot_asset__bundle__service__pb2.AssetBundleQuery.SerializeToString,
            avikom_dot_unity_dot_asset__bundle__pb2.AssetBundle.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/generic/result.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61vikom/generic/result.proto\x12\x0e\x61vikom.generic\"T\n\x06Result\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12(\n\x05\x65rror\x18\x03 \x01(\x0e\x32\x19.avikom.generic.ErrorCode*\x81\x01\n\tErrorCode\x12\x0c\n\x08NO_ERROR\x10\x00\x12\x12\n\x0eINTERNAL_ERROR\x10\x01\x12\x13\n\x0f\x41TTRIBUTE_ERROR\x10\x02\x12\x0f\n\x0bVALUE_ERROR\x10\x03\x12\x11\n\rRUNTIME_ERROR\x10\x04\x12\x19\n\x15NOT_IMPLEMENTED_ERROR\x10\x05\x42l\n\x18\x61pp.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\xaa\x02\x14\x41vikom.Types.Genericb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.generic.result_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\252\002\024Avikom.Types.Generic'
  _ERRORCODE._serialized_start=134
  _ERRORCODE._serialized_end=263
  _RESULT._serialized_start=47
  _RESULT._serialized_end=131
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/vision/image_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.vision import image_info_pb2 as avikom_dot_vision_dot_image__info__pb2
from avikom.vision import image_pb2 as avikom_dot_vision_dot_image__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!avikom/vision/image_service.proto\x12\ravikom.vision\x1a\x1e\x61vikom/vision/image_info.proto\x1a\x19\x61vikom/vision/image.proto2\x8e\x01\n\x0cImageService\x12>\n\x08GetImage\x12\x18.avikom.vision.ImageInfo\x1a\x14.avikom.vision.Image\"\x00\x30\x01\x12>\n\x08GetVideo\x12\x18.avikom.vision.ImageInfo\x1a\x14.avikom.vision.Image\"\x00\x30\x01\x42i\n\x17\x61pp.avikom.types.visionZ8gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/vision\xaa\x02\x13\x41vikom.Types.Visionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.vision.image_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027app.avikom.types.visionZ8gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/vision\252\002\023Avikom.Types.Vision'
  _IMAGESERVICE._serialized_start=112
  _IMAGESERVICE._serialized_end=254
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from avikom.glasses import calibration_service_pb2 as avikom_dot_glasses_dot_calibration__service__pb2
from avikom.unity import game_object_pb2 as avikom_dot_unity_dot_game__object__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class CalibrationServiceStub(object):
    """*
    This service can be used to retrieve information about the system's calibration state.
    It is primarily intended for spatial computing devices that synchronize digital and real-world artifacts with so called space pins.
    Note: right now, AVIKOM calibrates 'on the fly' and does not make use of this interface.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetUncalibratedSpacePin = channel.unary_unary(
                '/avikom.glasses.CalibrationService/GetUncalibratedSpacePin',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=avikom_dot_unity_dot_game__object__pb2.GameObject.FromString,
                )
        self.GetSpacePinNames = channel.unary_unary(
                '/avikom.glasses.CalibrationService/GetSpacePinNames',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=avikom_dot_glasses_dot_calibration__service__pb2.SpacePinNames.FromString,
                )


class CalibrationServiceServicer(object):
    """*
    This service can be used to retrieve information about the system's calibration state.
    It is primarily intended for spatial computing devices that synchronize digital and real-world artifacts with so called space pins.
    Note: right now, AVIKOM calibrates 'on the fly' and does not make use of this interface.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def GetUncalibratedSpacePin(self, request, context):
        """/ returns the next uncalibrated/unassigned anchor/space pin
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSpacePinNames(self, request, context):
        """/ get the names of all world anchors/space pins; intended for situations where the user should decide which target to calibrate next
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CalibrationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetUncalibratedSpacePin': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUncalibratedSpacePin,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=avikom_dot_unity_dot_game__object__pb2.GameObject.SerializeToString,
            ),
            'GetSpacePinNames': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSpacePinNames,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=avikom_dot_glasses_dot_calibration__service__pb2.SpacePinNames.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'avikom.glasses.CalibrationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CalibrationService(object):
    """*
    This service can be used to retrieve information about the system's calibration state.
    It is primarily intended for spatial computing devices that synchronize digital and real-world artifacts with so called space pins.
    Note: right now, AVIKOM calibrates 'on the fly' and does not make use of this interface.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    @staticmethod
    def GetUncalibratedSpacePin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.glasses.CalibrationService/GetUncalibratedSpacePin',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            avikom_dot_unity_dot_game__object__pb2.GameObject.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSpacePinNames(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.glasses.CalibrationService/GetSpacePinNames',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            avikom_dot_glasses_dot_calibration__service__pb2.SpacePinNames.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/generic/stream_request.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from avikom.generic import peer_pb2 as avikom_dot_generic_dot_peer__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#avikom/generic/stream_request.proto\x12\x0e\x61vikom.generic\x1a\x1b\x61vikom/generic/result.proto\x1a\x19\x61vikom/generic/peer.proto\x1a\x1bgoogle/protobuf/empty.proto\"\xeb\x01\n\rStreamRequest\x12*\n\x08protocol\x18\x01 \x01(\x0e\x32\x18.avikom.generic.Protocol\x12\x33\n\raudio_quality\x18\x02 \x01(\x0e\x32\x1c.avikom.generic.AudioQuality\x12\x33\n\rvideo_quality\x18\x03 \x01(\x0e\x32\x1c.avikom.generic.VideoQuality\x12\x16\n\x0esend_augmented\x18\x04 \x01(\x08\x12\x15\n\rreceive_audio\x18\x05 \x01(\x08\x12\x15\n\rreceive_video\x18\x06 \x01(\x08*4\n\x08Protocol\x12\x10\n\x0cPROTOCOL_TCP\x10\x00\x12\x16\n\x12PROTOCOL_WEBSOCKET\x10\x01*v\n\x0cVideoQuality\x12\x16\n\x12QUALITY_VIDEO_NONE\x10\x00\x12\x18\n\x14QUALITY_VIDEO_LOWEST\x10\x01\x12\x19\n\x15QUALITY_VIDEO_DEFAULT\x10\x05\x12\x19\n\x15QUALITY_VIDEO_HIGHEST\x10\n*v\n\x0c\x41udioQuality\x12\x16\n\x12QUALITY_AUDIO_NONE\x10\x00\x12\x18\n\x14QUALITY_AUDIO_LOWEST\x10\x01\x12\x19\n\x15QUALITY_AUDIO_DEFAULT\x10\x05\x12\x19\n\x15QUALITY_AUDIO_HIGHEST\x10\n2\xa3\x01\n\x14StreamRequestService\x12\x43\n\nInitStream\x12\x1d.avikom.generic.StreamRequest\x1a\x14.avikom.generic.Peer\"\x00\x12\x46\n\x0b\x43loseStream\x12\x1d.avikom.generic.StreamRequest\x1a\x16.google.protobuf.Empty\"\x00\x42l\n\x18\x61pp.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\xaa\x02\x14\x41vikom.Types.Genericb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.generic.stream_request_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\252\002\024Avikom.Types.Generic'
  _PROTOCOL._serialized_start=378
  _PROTOCOL._serialized_end=430
  _VIDEOQUALITY._serialized_start=432
  _VIDEOQUALITY._serialized_end=550
  _AUDIOQUALITY._serialized_start=552
  _AUDIOQUALITY._serialized_end=670
  _STREAMREQUEST._serialized_start=141
  _STREAMREQUEST._serialized_end=376
  _STREAMREQUESTSERVICE._serialized_start=673
  _STREAMREQUESTSERVICE._serialized_end=836
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Vector3D(google.protobuf.message.Message):
    """*
    A simple 3D float vector.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    X_FIELD_NUMBER: builtins.int
    Y_FIELD_NUMBER: builtins.int
    Z_FIELD_NUMBER: builtins.int
    x: builtins.float
    """/ x-axis component"""
    y: builtins.float
    """/ y-axis component"""
    z: builtins.float
    """/ z-axis component"""
    def __init__(
        self,
        *,
        x: builtins.float = ...,
        y: builtins.float = ...,
        z: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["x", b"x", "y", b"y", "z", b"z"]) -> None: ...

global___Vector3D = Vector3D



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.assistance.assistance_level_pb2
import avikom.generic.modality_pb2
import avikom.unity.transpose_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class InstructionMeta(google.protobuf.message.Message):
    """*
    This message describes the common base for an instruction.
    Every instruction has an assistance level and can be modaly modulated
    They should all be compatible with the 'Basic Action Concept' (BAC) of SDA-M.
    @author: Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSISTANCE_LEVEL_FIELD_NUMBER: builtins.int
    MODAL_BIAS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    TRANSPOSE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    assistance_level: avikom.assistance.assistance_level_pb2.AssistanceLevel.ValueType
    """/ the targeted assistance level, this instruction wont be available for users with less assistance requirements"""
    @property
    def modal_bias(self) -> avikom.generic.modality_pb2.Modality:
        """/ whether an instruction should be preferably presented in a certain modality and whether a modality in generally unsuited for that introduction."""
    location: builtins.str
    """/ name of the scene/task asset this object should be referenced to;"""
    @property
    def transpose(self) -> avikom.unity.transpose_pb2.Transpose:
        """/ relative offset to the mentioned location"""
    id: builtins.str
    """/ an optional id to reference the instruction later"""
    def __init__(
        self,
        *,
        assistance_level: avikom.assistance.assistance_level_pb2.AssistanceLevel.ValueType = ...,
        modal_bias: avikom.generic.modality_pb2.Modality | None = ...,
        location: builtins.str = ...,
        transpose: avikom.unity.transpose_pb2.Transpose | None = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["modal_bias", b"modal_bias", "transpose", b"transpose"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["assistance_level", b"assistance_level", "id", b"id", "location", b"location", "modal_bias", b"modal_bias", "transpose", b"transpose"]) -> None: ...

global___InstructionMeta = InstructionMeta



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/camunda/variable.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61vikom/camunda/variable.proto\x12\x0e\x61vikom.camunda\"V\n\x08Variable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12-\n\nvalue_type\x18\x02 \x01(\x0e\x32\x19.avikom.camunda.ValueType\x12\r\n\x05value\x18\x03 \x01(\t*O\n\tValueType\x12\x0e\n\nTYPE_UNSET\x10\x00\x12\x0f\n\x0bTYPE_STRING\x10\x01\x12\x0f\n\x0bTYPE_NUMBER\x10\x02\x12\x10\n\x0cTYPE_BOOLEAN\x10\x03\x42l\n\x18\x61pp.avikom.types.camundaZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/camunda\xaa\x02\x14\x41vikom.Types.Camundab\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.camunda.variable_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.camundaZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/camunda\252\002\024Avikom.Types.Camunda'
  _VALUETYPE._serialized_start=137
  _VALUETYPE._serialized_end=216
  _VARIABLE._serialized_start=49
  _VARIABLE._serialized_end=135
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.generic.modality_pb2
import avikom.generic.user_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class UserProfile(google.protobuf.message.Message):
    """*
    A more elaborate profile of a user including additional data (i.e. "Stammdaten").
    User Attribution is mandatory, all other fields are optional
    @author: Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    DEPARTMENT_FIELD_NUMBER: builtins.int
    PHONE_NUMBER_FIELD_NUMBER: builtins.int
    POSITION_FIELD_NUMBER: builtins.int
    MODAL_PREFERENCES_FIELD_NUMBER: builtins.int
    ASSISTANCE_DECREASE_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> avikom.generic.user_pb2.User:
        """/ the user object that belongs to this profile; mandatory information"""
    email: builtins.str
    """/ a valid e-mail address to contact the user; optional information"""
    department: builtins.str
    """/ the department the user works in; optional information"""
    phone_number: builtins.str
    """/ a phone number under which the user can be reached; optional information"""
    position: builtins.str
    """/ the job title of the user; optional information"""
    @property
    def modal_preferences(self) -> avikom.generic.modality_pb2.Modality:
        """/ indicating if the user prefers a specific modality above others; optional information"""
    assistance_decrease: builtins.float
    """/ the "velocity" with which amount of assistance is decreased; 0 means no decrease; 1 max. decrease?; optional information"""
    def __init__(
        self,
        *,
        user: avikom.generic.user_pb2.User | None = ...,
        email: builtins.str = ...,
        department: builtins.str = ...,
        phone_number: builtins.str = ...,
        position: builtins.str = ...,
        modal_preferences: avikom.generic.modality_pb2.Modality | None = ...,
        assistance_decrease: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["modal_preferences", b"modal_preferences", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["assistance_decrease", b"assistance_decrease", "department", b"department", "email", b"email", "modal_preferences", b"modal_preferences", "phone_number", b"phone_number", "position", b"position", "user", b"user"]) -> None: ...

global___UserProfile = UserProfile



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/glasses/calibration_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.unity import game_object_pb2 as avikom_dot_unity_dot_game__object__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(avikom/glasses/calibration_service.proto\x12\x0e\x61vikom.glasses\x1a\x1e\x61vikom/unity/game_object.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\"\x1e\n\rSpacePinNames\x12\r\n\x05names\x18\x01 \x03(\t2\xb0\x01\n\x12\x43\x61librationService\x12M\n\x17GetUncalibratedSpacePin\x12\x16.google.protobuf.Empty\x1a\x18.avikom.unity.GameObject\"\x00\x12K\n\x10GetSpacePinNames\x12\x16.google.protobuf.Empty\x1a\x1d.avikom.glasses.SpacePinNames\"\x00\x42l\n\x18\x61pp.avikom.types.glassesZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/glasses\xaa\x02\x14\x41vikom.Types.Glassesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.glasses.calibration_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.glassesZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/glasses\252\002\024Avikom.Types.Glasses'
  _SPACEPINNAMES._serialized_start=151
  _SPACEPINNAMES._serialized_end=181
  _CALIBRATIONSERVICE._serialized_start=184
  _CALIBRATIONSERVICE._serialized_end=360
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/task_stereotype.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.assistance import service_configuration_pb2 as avikom_dot_assistance_dot_service__configuration__pb2
from avikom.assistance import choices_config_pb2 as avikom_dot_assistance_dot_choices__config__pb2
from avikom.assistance import assistance_level_pb2 as avikom_dot_assistance_dot_assistance__level__pb2
from avikom.unity import game_object_pb2 as avikom_dot_unity_dot_game__object__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'avikom/assistance/task_stereotype.proto\x12\x11\x61vikom.assistance\x1a-avikom/assistance/service_configuration.proto\x1a&avikom/assistance/choices_config.proto\x1a(avikom/assistance/assistance_level.proto\x1a\x1e\x61vikom/unity/game_object.proto\"\xe8\x02\n\x0eTaskStereotype\x12;\n\x08\x63\x61tegory\x18\x01 \x01(\x0e\x32).avikom.assistance.TaskStereotypeCategory\x12\x31\n\x07\x63hoices\x18\x05 \x01(\x0b\x32 .avikom.assistance.ChoicesConfig\x12\x0e\n\x06target\x18\x06 \x01(\t\x12\x39\n\x08services\x18\x07 \x03(\x0b\x32\'.avikom.assistance.ServiceConfiguration\x12>\n\x12\x64\x65\x66\x61ult_assistance\x18\n \x01(\x0e\x32\".avikom.assistance.AssistanceLevel\x12>\n\x12minimal_assistance\x18\x0b \x01(\x0e\x32\".avikom.assistance.AssistanceLevel\x12\x1b\n\x13\x61ssistance_decrease\x18\x0c \x01(\x02*\xa4\x01\n\x16TaskStereotypeCategory\x12\x0f\n\x0bTASK_UNKOWN\x10\x00\x12\x10\n\x0cTASK_PENDING\x10\x01\x12\x11\n\rTASK_DECISION\x10\x02\x12\x0f\n\x0bTASK_ASSIGN\x10\x03\x12\x0e\n\nTASK_GUIDE\x10\x04\x12\x10\n\x0cTASK_APPROVE\x10\x05\x12\x0e\n\nTASK_INPUT\x10\x06\x12\x11\n\rTASK_INTERNAL\x10\x07\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.task_stereotype_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _TASKSTEREOTYPECATEGORY._serialized_start=587
  _TASKSTEREOTYPECATEGORY._serialized_end=751
  _TASKSTEREOTYPE._serialized_start=224
  _TASKSTEREOTYPE._serialized_end=584
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from avikom.unity import asset_bundle_pb2 as avikom_dot_unity_dot_asset__bundle__pb2
from avikom.unity import game_object_pb2 as avikom_dot_unity_dot_game__object__pb2
from avikom.unity import game_object_service_pb2 as avikom_dot_unity_dot_game__object__service__pb2


class GameObjectServiceStub(object):
    """*
    Provides an interface to add virtual objects to the current scene.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Add = channel.unary_unary(
                '/avikom.unity.GameObjectService/Add',
                request_serializer=avikom_dot_unity_dot_game__object__pb2.GameObject.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.Set = channel.unary_unary(
                '/avikom.unity.GameObjectService/Set',
                request_serializer=avikom_dot_unity_dot_game__object__pb2.GameObject.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.Get = channel.unary_unary(
                '/avikom.unity.GameObjectService/Get',
                request_serializer=avikom_dot_unity_dot_game__object__service__pb2.GameObjectQuery.SerializeToString,
                response_deserializer=avikom_dot_unity_dot_game__object__pb2.GameObject.FromString,
                )
        self.AddBundle = channel.stream_unary(
                '/avikom.unity.GameObjectService/AddBundle',
                request_serializer=avikom_dot_unity_dot_asset__bundle__pb2.AssetBundle.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )


class GameObjectServiceServicer(object):
    """*
    Provides an interface to add virtual objects to the current scene.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def Add(self, request, context):
        """/ adds an object to the scene
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Set(self, request, context):
        """/ updates properties if a previously added object
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """/ returns current properties of a scene object
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddBundle(self, request_iterator, context):
        """/ uploads a bundle of assets that can be used for the creation of new objects
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GameObjectServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Add': grpc.unary_unary_rpc_method_handler(
                    servicer.Add,
                    request_deserializer=avikom_dot_unity_dot_game__object__pb2.GameObject.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'Set': grpc.unary_unary_rpc_method_handler(
                    servicer.Set,
                    request_deserializer=avikom_dot_unity_dot_game__object__pb2.GameObject.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=avikom_dot_unity_dot_game__object__service__pb2.GameObjectQuery.FromString,
                    response_serializer=avikom_dot_unity_dot_game__object__pb2.GameObject.SerializeToString,
            ),
            'AddBundle': grpc.stream_unary_rpc_method_handler(
                    servicer.AddBundle,
                    request_deserializer=avikom_dot_unity_dot_asset__bundle__pb2.AssetBundle.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'avikom.unity.GameObjectService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class GameObjectService(object):
    """*
    Provides an interface to add virtual objects to the current scene.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    @staticmethod
    def Add(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.unity.GameObjectService/Add',
            avikom_dot_unity_dot_game__object__pb2.GameObject.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Set(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.unity.GameObjectService/Set',
            avikom_dot_unity_dot_game__object__pb2.GameObject.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.unity.GameObjectService/Get',
            avikom_dot_unity_dot_game__object__service__pb2.GameObjectQuery.SerializeToString,
            avikom_dot_unity_dot_game__object__pb2.GameObject.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddBundle(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/avikom.unity.GameObjectService/AddBundle',
            avikom_dot_unity_dot_asset__bundle__pb2.AssetBundle.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from avikom.unity import scene_config_pb2 as avikom_dot_unity_dot_scene__config__pb2
from avikom.unity import scene_config_storage_service_pb2 as avikom_dot_unity_dot_scene__config__storage__service__pb2
from avikom.unity import task_config_pb2 as avikom_dot_unity_dot_task__config__pb2


class SceneConfigStorageServiceStub(object):
    """*
    This services provides and receives scene configurations and task-specific configurations.
    Scene and task configurations 'stack' and must not ne contradicting.
    There is always just one config for a scene and a task.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AddSceneConfig = channel.unary_unary(
                '/avikom.unity.SceneConfigStorageService/AddSceneConfig',
                request_serializer=avikom_dot_unity_dot_scene__config__pb2.SceneConfig.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.GetSceneConfig = channel.unary_unary(
                '/avikom.unity.SceneConfigStorageService/GetSceneConfig',
                request_serializer=avikom_dot_unity_dot_scene__config__storage__service__pb2.SceneConfigQuery.SerializeToString,
                response_deserializer=avikom_dot_unity_dot_scene__config__pb2.SceneConfig.FromString,
                )
        self.UpdateSceneConfig = channel.unary_unary(
                '/avikom.unity.SceneConfigStorageService/UpdateSceneConfig',
                request_serializer=avikom_dot_unity_dot_scene__config__pb2.SceneConfig.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.AddTaskConfig = channel.unary_unary(
                '/avikom.unity.SceneConfigStorageService/AddTaskConfig',
                request_serializer=avikom_dot_unity_dot_task__config__pb2.TaskConfig.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.GetTaskConfig = channel.unary_unary(
                '/avikom.unity.SceneConfigStorageService/GetTaskConfig',
                request_serializer=avikom_dot_unity_dot_scene__config__storage__service__pb2.TaskConfigQuery.SerializeToString,
                response_deserializer=avikom_dot_unity_dot_task__config__pb2.TaskConfig.FromString,
                )
        self.UpdateTaskConfig = channel.unary_unary(
                '/avikom.unity.SceneConfigStorageService/UpdateTaskConfig',
                request_serializer=avikom_dot_unity_dot_task__config__pb2.TaskConfig.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )


class SceneConfigStorageServiceServicer(object):
    """*
    This services provides and receives scene configurations and task-specific configurations.
    Scene and task configurations 'stack' and must not ne contradicting.
    There is always just one config for a scene and a task.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def AddSceneConfig(self, request, context):
        """/ adds a scene configuration for an EXISTING scene to the storage; raises exceptions when the scene config already exists
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSceneConfig(self, request, context):
        """/ returns a scene configuration to a given `scene_name`
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSceneConfig(self, request, context):
        """/ updates an existing scene configuration; raises an exception if it does not exist
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddTaskConfig(self, request, context):
        """/ adds a task configuration for an EXISTING task to the storage; raises exceptions when the task config already exists
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTaskConfig(self, request, context):
        """/ returns a task configuration to a given `task_name`
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTaskConfig(self, request, context):
        """/ updates an existing task configuration; raises an exception if it does not exist
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SceneConfigStorageServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AddSceneConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.AddSceneConfig,
                    request_deserializer=avikom_dot_unity_dot_scene__config__pb2.SceneConfig.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'GetSceneConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSceneConfig,
                    request_deserializer=avikom_dot_unity_dot_scene__config__storage__service__pb2.SceneConfigQuery.FromString,
                    response_serializer=avikom_dot_unity_dot_scene__config__pb2.SceneConfig.SerializeToString,
            ),
            'UpdateSceneConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSceneConfig,
                    request_deserializer=avikom_dot_unity_dot_scene__config__pb2.SceneConfig.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'AddTaskConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.AddTaskConfig,
                    request_deserializer=avikom_dot_unity_dot_task__config__pb2.TaskConfig.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'GetTaskConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTaskConfig,
                    request_deserializer=avikom_dot_unity_dot_scene__config__storage__service__pb2.TaskConfigQuery.FromString,
                    response_serializer=avikom_dot_unity_dot_task__config__pb2.TaskConfig.SerializeToString,
            ),
            'UpdateTaskConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTaskConfig,
                    request_deserializer=avikom_dot_unity_dot_task__config__pb2.TaskConfig.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'avikom.unity.SceneConfigStorageService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SceneConfigStorageService(object):
    """*
    This services provides and receives scene configurations and task-specific configurations.
    Scene and task configurations 'stack' and must not ne contradicting.
    There is always just one config for a scene and a task.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    @staticmethod
    def AddSceneConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.unity.SceneConfigStorageService/AddSceneConfig',
            avikom_dot_unity_dot_scene__config__pb2.SceneConfig.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSceneConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.unity.SceneConfigStorageService/GetSceneConfig',
            avikom_dot_unity_dot_scene__config__storage__service__pb2.SceneConfigQuery.SerializeToString,
            avikom_dot_unity_dot_scene__config__pb2.SceneConfig.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSceneConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.unity.SceneConfigStorageService/UpdateSceneConfig',
            avikom_dot_unity_dot_scene__config__pb2.SceneConfig.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddTaskConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.unity.SceneConfigStorageService/AddTaskConfig',
            avikom_dot_unity_dot_task__config__pb2.TaskConfig.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTaskConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.unity.SceneConfigStorageService/GetTaskConfig',
            avikom_dot_unity_dot_scene__config__storage__service__pb2.TaskConfigQuery.SerializeToString,
            avikom_dot_unity_dot_task__config__pb2.TaskConfig.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTaskConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.unity.SceneConfigStorageService/UpdateTaskConfig',
            avikom_dot_unity_dot_task__config__pb2.TaskConfig.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.assistance.runtime_task_step_pb2
import avikom.generic.peer_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class RuntimeStepList(google.protobuf.message.Message):
    """*
    A list of `RuntimeTaskSteps`. It also contains a list of `Peers` which can be used to conduct the passed steps.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STEPS_FIELD_NUMBER: builtins.int
    PEERS_FIELD_NUMBER: builtins.int
    @property
    def steps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.assistance.runtime_task_step_pb2.RuntimeTaskStep]:
        """/ currently active task steps to be done"""
    @property
    def peers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.generic.peer_pb2.Peer]:
        """/ a list of peers that can be used to solve task steps"""
    def __init__(
        self,
        *,
        steps: collections.abc.Iterable[avikom.assistance.runtime_task_step_pb2.RuntimeTaskStep] | None = ...,
        peers: collections.abc.Iterable[avikom.generic.peer_pb2.Peer] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["peers", b"peers", "steps", b"steps"]) -> None: ...

global___RuntimeStepList = RuntimeStepList
